<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Verwijderen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Beeldvullende modus</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Diavoorstelling</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporteren</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopiëren</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Foto-informatie</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Video-informatie</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Herstellen</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Maken</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Nieuw album</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Weet je zeker dat je dit album wilt verwijderen?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>of sleep foto&apos;s hierheen</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Alles importeren</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importeren naar:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Systeemschijf</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerij</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>De schijf is bezig en kan daarom niet worden uitgeworpen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Negeren</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Bezig met laden…</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>De bestanden worden verwijderd na het vermelde aantal dagen</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Vervangen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Opslaan in:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Bestandsformaat:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kwaliteit:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Kies andere mappen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Voer een bestandsnaam in</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>bestaat al. Wil je deze vervangen?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>Schermfoto</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Tekenen</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(kopie)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1-schijf</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Blanco %1-schijf</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1-versleuteld</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1-schijf</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Foto&apos;s exporteren</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Bezig met verwijderen…</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Bezig met herstellen…</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>Weet je zeker dat je dit bestand wilt verwijderen?</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>Je kunt het nadien niet meer herstellen.</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>Weet je zeker dat je %1 bestanden wilt verwijderen?</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>Je kunt ze nadien niet meer herstellen.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>Weet je zeker dat je dit bestand lokaal wilt verwijderen?</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>Je kunt het nadien vanuit de prullenbak herstellen.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>Weet je zeker dat je %1 bestanden lokaal wilt verwijderen?</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>Je kunt ze nadien vanuit de prullenbak herstellen.</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Afbeeldingsinformatie</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
            <numerusform>%n foto&apos;s</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n video&apos;s</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n item</numerusform>
            <numerusform>%n items</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importeer foto&apos;s en video&apos;s</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>of sleep ze hierheen</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Alle foto&apos;s en video&apos;s</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Geen foto&apos;s of video&apos;s aangetroffen</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Apparaat</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerij</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albums</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Album is een mooi vormgegeven programma waarmee je foto&apos;s en video&apos;s kunt bekijken en beheren.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Foto&apos;s</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Albumnaam wijzigen</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Het album &apos;%1&apos; is verwijderd</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Toegevoegd aan &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importeren voltooid</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Importeren mislukt</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exporteren mislukt</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Exporteren voltooid</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Alle foto&apos;s</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Tijdlijn</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albums</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Beeldvullende modus verlaten</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pagina omhoog</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pagina omlaag</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Bezig met importeren…</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Alle foto&apos;s en video&apos;s</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Importeer foto&apos;s en video&apos;s</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Geen foto&apos;s of video&apos;s aangetroffen</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Foto&apos;s exporteren</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Foto&apos;s/Video&apos;s importeren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Foto-/Video-informatie</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Importeer foto&apos;s en video&apos;s</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>Mappen importeren</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>Het importeren is onderbroken</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>Deze locatie kan niet worden toegevoegd</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>Deze locatie is al toegevoegd</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1 bestanden kunnen niet worden hersteld omdat de bestandsnaam te lang is</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flits</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Genomen op</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Aangepast op</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtingsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtingsprogramma</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtingstijd</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafragma</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brandpuntsafstand</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max. diafragma</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Meetmodus</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Witbalans</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flitscompensatie</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Cameramodel</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lensmodel</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Kleurruimte</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Systeemschijf</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Selecteren</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Niets selecteren</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Geïmporteerd op</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Geïmporteerd op</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles selecteren</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Niets selecteren</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Foto&apos;s</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Bezig met importeren…</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 items geïmporteerd</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 items verwijderd</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 items geïmporteerd - %2 mislukt</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 foto geselecteerd</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 video geselecteerd</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>De foto/video is al aanwezig</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>%n foto geselecteerd</numerusform>
            <numerusform>%n foto&apos;s geselecteerd</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>%n video geselecteerd</numerusform>
            <numerusform>%n video&apos;s geselecteerd</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>%n item geselecteerd</numerusform>
            <numerusform>%n items geselecteerd</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 items geïmporteerd - %2 items reeds aanwezig</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Geen zoekresultaten</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 foto gevonden</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>%n video gevonden</numerusform>
            <numerusform>%n video&apos;s gevonden</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 video gevonden</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>%n item gevonden</numerusform>
            <numerusform>%n items gevonden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>%n foto gevonden</numerusform>
            <numerusform>%n foto&apos;s gevonden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
            <numerusform>%n foto&apos;s</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n video&apos;s</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Bezig met importeren van %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Bezig met exporteren van %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullende modus</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Foto-informatie</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Toevoegen aan album</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video-informatie</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dagen</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
            <numerusform>%n foto&apos;s</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
            <numerusform>%n video&apos;s</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n item</numerusform>
            <numerusform>%n items</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Codecinformatie</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Audio-informatie</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Videocodec-id</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Videocoderingssnelheid</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Beeldverhouding</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolutie</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Audiocodec-id</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Audiocoderingssnelheid</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Audio digit</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanaal</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Sampling</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Aangepast op</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video-informatie</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Genomen op</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
</TS>
